package com.jclark.xml.parse;

import java.util.Enumeration;
import java.net.URL;

/**
 * Information about a DTD.
 */
public interface DTD {
  /**
   * Returns an enumeration over the names of general entities declared in
   * the DTD.
   */
  Enumeration entityNames();
  /**
   * Returns an enumeration over the names of notations declared in
   * the DTD.
   */
  Enumeration notationNames();
  /**
   * Returns the system identifier for a notation.
   * Returns null if the notation was not declared or no system identifier
   * was specified.
   * A relative URL is not automatically resolved into an absolute URL;
   * <code>getNotationBase</code> can be used to do this.
   *
   * @see #getNotationBase
   */
  String getNotationSystemId(String notationName);
  /**
   * Returns the public identifier for a notation.
   * Returns null if the notation was not declared or no public identifier
   * was specified.
   */
  String getNotationPublicId(String notationName);
  /**
   * Returns the URL of the entity in which the notation was declared.
   * Returns null if the entity was not declared or the URL of the
   * declaring entity is not available.
   */
  URL getNotationBase(String notationName);
  /**
   * Returns the replacement text of the specified general entity.
   * Returns null if the entity was not declared or was
   * as an external entity.
   */
  String getEntityReplacementText(String entityName);
  /**
   * Returns the system identifier for a general entity.
   * Returns null if the entity was not declared or is an internal entity.
   * A relative URL is not automatically resolved into an absolute URL;
   * <code>getNotationBase</code> can be used to do this.
   *
   * @see #getEntityBase
   */
  String getEntitySystemId(String entityName);
  /**
   * Returns the public identifier for a general entity.
   * Returns null if the entity was not declared or no public identifier
   * was specified.
   */
  String getEntityPublicId(String entityName);
  /**
   * Returns the name of the notation of an unparsed general entity.
   * Returns null if the entity was not declared or was a parsed entity.
   */
  String getEntityNotationName(String entityName);
  /**
   * Returns the URL of the entity in which the general entity was declared.
   * Returns null if the entity was not declared or the URL of the
   * declaring entity is not available.
   */
  URL getEntityBase(String entityName);
  /**
   * Returns true if an element type was declared to have element content.
   */
  boolean getElementTypeElementContent(String elementTypeName);
  /**
   * Returns true if the complete DTD was processed.
   */
  boolean isComplete();
  /**
   * Returns true if <code>standalone="yes"</code> was specified in the
   * XML declaration.
   */
  boolean isStandalone();
}
